# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["DetailGetByLocationParams"]


class DetailGetByLocationParams(TypedDict, total=False):
    lat: Required[float]
    """Latitude coordinate"""

    lon: Required[float]
    """Longitude coordinate"""

    page: int
    """Page number for results"""

    page_size: Annotated[int, PropertyInfo(alias="pageSize")]
    """Number of results per page (max 100)"""

    radius: float
    """Search radius in kilometers (max 80km)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .ids import (
    IDsResource,
    AsyncIDsResource,
    IDsResourceWithRawResponse,
    AsyncIDsResourceWithRawResponse,
    IDsResourceWithStreamingResponse,
    AsyncIDsResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.partner.v1.production.production_details import ProductionDetails

__all__ = ["ProductionResource", "AsyncProductionResource"]


class ProductionResource(SyncAPIResource):
    @cached_property
    def ids(self) -> IDsResource:
        return IDsResource(self._client)

    @cached_property
    def details(self) -> DetailsResource:
        return DetailsResource(self._client)

    @cached_property
    def search(self) -> SearchResource:
        return SearchResource(self._client)

    @cached_property
    def with_raw_response(self) -> ProductionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return ProductionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProductionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return ProductionResourceWithStreamingResponse(self)

    def get_by_vendor_production_id(
        self,
        vendor_production_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProductionDetails:
        """
        Returns production details for a vendor-specific production ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_production_id:
            raise ValueError(
                f"Expected a non-empty value for `vendor_production_id` but received {vendor_production_id!r}"
            )
        return self._get(
            f"/partner/v1/productions/byVendorProductionId/{vendor_production_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductionDetails,
        )


class AsyncProductionResource(AsyncAPIResource):
    @cached_property
    def ids(self) -> AsyncIDsResource:
        return AsyncIDsResource(self._client)

    @cached_property
    def details(self) -> AsyncDetailsResource:
        return AsyncDetailsResource(self._client)

    @cached_property
    def search(self) -> AsyncSearchResource:
        return AsyncSearchResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncProductionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncProductionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProductionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncProductionResourceWithStreamingResponse(self)

    async def get_by_vendor_production_id(
        self,
        vendor_production_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProductionDetails:
        """
        Returns production details for a vendor-specific production ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_production_id:
            raise ValueError(
                f"Expected a non-empty value for `vendor_production_id` but received {vendor_production_id!r}"
            )
        return await self._get(
            f"/partner/v1/productions/byVendorProductionId/{vendor_production_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductionDetails,
        )


class ProductionResourceWithRawResponse:
    def __init__(self, production: ProductionResource) -> None:
        self._production = production

        self.get_by_vendor_production_id = to_raw_response_wrapper(
            production.get_by_vendor_production_id,
        )

    @cached_property
    def ids(self) -> IDsResourceWithRawResponse:
        return IDsResourceWithRawResponse(self._production.ids)

    @cached_property
    def details(self) -> DetailsResourceWithRawResponse:
        return DetailsResourceWithRawResponse(self._production.details)

    @cached_property
    def search(self) -> SearchResourceWithRawResponse:
        return SearchResourceWithRawResponse(self._production.search)


class AsyncProductionResourceWithRawResponse:
    def __init__(self, production: AsyncProductionResource) -> None:
        self._production = production

        self.get_by_vendor_production_id = async_to_raw_response_wrapper(
            production.get_by_vendor_production_id,
        )

    @cached_property
    def ids(self) -> AsyncIDsResourceWithRawResponse:
        return AsyncIDsResourceWithRawResponse(self._production.ids)

    @cached_property
    def details(self) -> AsyncDetailsResourceWithRawResponse:
        return AsyncDetailsResourceWithRawResponse(self._production.details)

    @cached_property
    def search(self) -> AsyncSearchResourceWithRawResponse:
        return AsyncSearchResourceWithRawResponse(self._production.search)


class ProductionResourceWithStreamingResponse:
    def __init__(self, production: ProductionResource) -> None:
        self._production = production

        self.get_by_vendor_production_id = to_streamed_response_wrapper(
            production.get_by_vendor_production_id,
        )

    @cached_property
    def ids(self) -> IDsResourceWithStreamingResponse:
        return IDsResourceWithStreamingResponse(self._production.ids)

    @cached_property
    def details(self) -> DetailsResourceWithStreamingResponse:
        return DetailsResourceWithStreamingResponse(self._production.details)

    @cached_property
    def search(self) -> SearchResourceWithStreamingResponse:
        return SearchResourceWithStreamingResponse(self._production.search)


class AsyncProductionResourceWithStreamingResponse:
    def __init__(self, production: AsyncProductionResource) -> None:
        self._production = production

        self.get_by_vendor_production_id = async_to_streamed_response_wrapper(
            production.get_by_vendor_production_id,
        )

    @cached_property
    def ids(self) -> AsyncIDsResourceWithStreamingResponse:
        return AsyncIDsResourceWithStreamingResponse(self._production.ids)

    @cached_property
    def details(self) -> AsyncDetailsResourceWithStreamingResponse:
        return AsyncDetailsResourceWithStreamingResponse(self._production.details)

    @cached_property
    def search(self) -> AsyncSearchResourceWithStreamingResponse:
        return AsyncSearchResourceWithStreamingResponse(self._production.search)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .showtime_details import ShowtimeDetails as ShowtimeDetails
from .detail_get_by_ids_params import DetailGetByIDsParams as DetailGetByIDsParams
from .detail_get_by_venue_params import DetailGetByVenueParams as DetailGetByVenueParams
from .detail_get_for_multiple_venues_params import DetailGetForMultipleVenuesParams as DetailGetForMultipleVenuesParams
from .detail_get_for_multiple_venues_response import (
    DetailGetForMultipleVenuesResponse as DetailGetForMultipleVenuesResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = [
    "DetailGetForMultipleVenuesResponse",
    "AttributeMap",
    "ProductionDetailsMap",
    "ProductionDetailsMapContributors",
    "ProductionDetailsMapContributorsCast",
    "ProductionDetailsMapContributorsCrew",
    "ProductionDetailsMapProductionMedia",
    "ProductionDetailsMapProductionMediaImageData",
    "ProductionDetailsMapProductionMediaTrailerData",
    "VenueShowtimeDetailsMap",
    "VenueShowtimeDetailsMapPreOrderDetail",
    "VenueShowtimeDetailsMapShowtimeDetail",
    "VenueShowtimeDetailsMapShowtimeDetailOfferData",
    "VenueShowtimeDetailsMapShowtimeDetailOfferDataOffer",
    "VenueShowtimeDetailsMapShowtimeDetailOfferDataOfferPrice",
]


class AttributeMap(BaseModel):
    id: Optional[str] = None
    """Attribute identifier"""

    description: Optional[str] = None
    """Attribute description"""

    friendly_name: Optional[str] = FieldInfo(alias="friendlyName", default=None)
    """User-friendly attribute name"""

    icon_url: Optional[str] = FieldInfo(alias="iconUrl", default=None)
    """URL to attribute icon"""

    type: Optional[str] = None
    """Attribute type"""


class ProductionDetailsMapContributorsCast(BaseModel):
    character_name: Optional[str] = FieldInfo(alias="characterName", default=None)
    """Character name"""

    name: Optional[str] = None
    """Actor name"""


class ProductionDetailsMapContributorsCrew(BaseModel):
    name: Optional[str] = None
    """Crew member name"""

    role: Optional[str] = None
    """Crew member role"""


class ProductionDetailsMapContributors(BaseModel):
    cast: Optional[List[ProductionDetailsMapContributorsCast]] = None
    """List of cast members"""

    crew: Optional[List[ProductionDetailsMapContributorsCrew]] = None
    """List of crew members"""


class ProductionDetailsMapProductionMediaImageData(BaseModel):
    cover_image_url: Optional[str] = FieldInfo(alias="coverImageUrl", default=None)
    """URL to cover image"""

    promo_image_urls: Optional[List[str]] = FieldInfo(alias="promoImageUrls", default=None)
    """URLs to promotional images"""


class ProductionDetailsMapProductionMediaTrailerData(BaseModel):
    trailer_urls: Optional[List[str]] = FieldInfo(alias="trailerUrls", default=None)
    """URLs to trailer videos"""


class ProductionDetailsMapProductionMedia(BaseModel):
    image_data: Optional[ProductionDetailsMapProductionMediaImageData] = FieldInfo(alias="imageData", default=None)

    trailer_data: Optional[ProductionDetailsMapProductionMediaTrailerData] = FieldInfo(
        alias="trailerData", default=None
    )


class ProductionDetailsMap(BaseModel):
    id: Optional[str] = None
    """Production identifier"""

    advisory_rating: Optional[str] = FieldInfo(alias="advisoryRating", default=None)
    """Advisory rating (PG, PG-13, R, etc.)"""

    atom_production_id: Optional[str] = FieldInfo(alias="atomProductionId", default=None)
    """Atom Tickets internal production ID"""

    atom_user_score: Optional[float] = FieldInfo(alias="atomUserScore", default=None)
    """User score on Atom Tickets"""

    contributors: Optional[ProductionDetailsMapContributors] = None

    distributor: Optional[str] = None
    """Distributor name"""

    genres: Optional[List[str]] = None
    """List of genres"""

    imdb_id: Optional[str] = FieldInfo(alias="imdbId", default=None)
    """IMDB identifier"""

    name: Optional[str] = None
    """Production name"""

    production_media: Optional[ProductionDetailsMapProductionMedia] = FieldInfo(alias="productionMedia", default=None)

    production_url: Optional[str] = FieldInfo(alias="productionUrl", default=None)
    """URL to production page on Atom Tickets"""

    release_date: Optional[str] = FieldInfo(alias="releaseDate", default=None)
    """Release date in format YYYY-MM-DD"""

    runtime_minutes: Optional[int] = FieldInfo(alias="runtimeMinutes", default=None)
    """Runtime in minutes"""

    synopsis: Optional[str] = None
    """Production synopsis"""


class VenueShowtimeDetailsMapPreOrderDetail(BaseModel):
    production_id: Optional[str] = FieldInfo(alias="productionId", default=None)
    """Production identifier"""

    showtime_days: Optional[List[str]] = FieldInfo(alias="showtimeDays", default=None)
    """List of days with showtimes available for pre-order"""

    venue_id: Optional[str] = FieldInfo(alias="venueId", default=None)
    """Venue identifier"""


class VenueShowtimeDetailsMapShowtimeDetailOfferDataOfferPrice(BaseModel):
    currency_code: Optional[str] = FieldInfo(alias="currencyCode", default=None)
    """Currency code (e.g., USD)"""

    value: Optional[float] = None
    """Price value"""


class VenueShowtimeDetailsMapShowtimeDetailOfferDataOffer(BaseModel):
    label: Optional[str] = None
    """Offer label (e.g., Matinee, Senior)"""

    price: Optional[VenueShowtimeDetailsMapShowtimeDetailOfferDataOfferPrice] = None


class VenueShowtimeDetailsMapShowtimeDetailOfferData(BaseModel):
    offers: Optional[List[VenueShowtimeDetailsMapShowtimeDetailOfferDataOffer]] = None
    """List of price offers"""


class VenueShowtimeDetailsMapShowtimeDetail(BaseModel):
    attributes: Optional[List[str]] = None
    """List of attribute keys for the attributeMap"""

    available_inventory: Optional[int] = FieldInfo(alias="availableInventory", default=None)
    """Number of available seats"""

    checkout_url: Optional[str] = FieldInfo(alias="checkoutUrl", default=None)
    """URL to checkout page on Atom Tickets"""

    local_showtime_start: Optional[datetime] = FieldInfo(alias="localShowtimeStart", default=None)
    """Local showtime start in ISO8601 format without milliseconds"""

    offer_data: Optional[VenueShowtimeDetailsMapShowtimeDetailOfferData] = FieldInfo(alias="offerData", default=None)

    production_id: Optional[str] = FieldInfo(alias="productionId", default=None)
    """Production identifier"""

    showtime_id: Optional[str] = FieldInfo(alias="showtimeId", default=None)
    """Showtime identifier"""

    tags: Optional[List[str]] = None
    """Tags for special event showtimes"""

    utc_showtime_start: Optional[datetime] = FieldInfo(alias="utcShowtimeStart", default=None)
    """UTC showtime start in ISO8601 format without milliseconds"""

    venue_id: Optional[str] = FieldInfo(alias="venueId", default=None)
    """Venue identifier"""


class VenueShowtimeDetailsMap(BaseModel):
    pre_order_details: Optional[List[VenueShowtimeDetailsMapPreOrderDetail]] = FieldInfo(
        alias="preOrderDetails", default=None
    )

    showtime_details: Optional[List[VenueShowtimeDetailsMapShowtimeDetail]] = FieldInfo(
        alias="showtimeDetails", default=None
    )


class DetailGetForMultipleVenuesResponse(BaseModel):
    attribute_map: Optional[Dict[str, AttributeMap]] = FieldInfo(alias="attributeMap", default=None)
    """Map of attribute keys to attribute details"""

    production_details_map: Optional[Dict[str, ProductionDetailsMap]] = FieldInfo(
        alias="productionDetailsMap", default=None
    )
    """Map of production IDs to production details"""

    venue_showtime_details_map: Optional[Dict[str, VenueShowtimeDetailsMap]] = FieldInfo(
        alias="venueShowtimeDetailsMap", default=None
    )
    """Map of venue IDs to venue showtime details"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .showtimes import (
    ShowtimesResource,
    AsyncShowtimesResource,
    ShowtimesResourceWithRawResponse,
    AsyncShowtimesResourceWithRawResponse,
    ShowtimesResourceWithStreamingResponse,
    AsyncShowtimesResourceWithStreamingResponse,
)
from ......_types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.partner.v1.venue.venue_details import VenueDetails

__all__ = ["ByVendorVenueIDResource", "AsyncByVendorVenueIDResource"]


class ByVendorVenueIDResource(SyncAPIResource):
    @cached_property
    def showtimes(self) -> ShowtimesResource:
        return ShowtimesResource(self._client)

    @cached_property
    def with_raw_response(self) -> ByVendorVenueIDResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return ByVendorVenueIDResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ByVendorVenueIDResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return ByVendorVenueIDResourceWithStreamingResponse(self)

    def get(
        self,
        vendor_venue_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VenueDetails:
        """
        Returns venue details for a vendor-specific venue ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_venue_id:
            raise ValueError(f"Expected a non-empty value for `vendor_venue_id` but received {vendor_venue_id!r}")
        return self._get(
            f"/partner/v1/venues/byVendorVenueId/{vendor_venue_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VenueDetails,
        )


class AsyncByVendorVenueIDResource(AsyncAPIResource):
    @cached_property
    def showtimes(self) -> AsyncShowtimesResource:
        return AsyncShowtimesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncByVendorVenueIDResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncByVendorVenueIDResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncByVendorVenueIDResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncByVendorVenueIDResourceWithStreamingResponse(self)

    async def get(
        self,
        vendor_venue_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VenueDetails:
        """
        Returns venue details for a vendor-specific venue ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_venue_id:
            raise ValueError(f"Expected a non-empty value for `vendor_venue_id` but received {vendor_venue_id!r}")
        return await self._get(
            f"/partner/v1/venues/byVendorVenueId/{vendor_venue_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VenueDetails,
        )


class ByVendorVenueIDResourceWithRawResponse:
    def __init__(self, by_vendor_venue_id: ByVendorVenueIDResource) -> None:
        self._by_vendor_venue_id = by_vendor_venue_id

        self.get = to_raw_response_wrapper(
            by_vendor_venue_id.get,
        )

    @cached_property
    def showtimes(self) -> ShowtimesResourceWithRawResponse:
        return ShowtimesResourceWithRawResponse(self._by_vendor_venue_id.showtimes)


class AsyncByVendorVenueIDResourceWithRawResponse:
    def __init__(self, by_vendor_venue_id: AsyncByVendorVenueIDResource) -> None:
        self._by_vendor_venue_id = by_vendor_venue_id

        self.get = async_to_raw_response_wrapper(
            by_vendor_venue_id.get,
        )

    @cached_property
    def showtimes(self) -> AsyncShowtimesResourceWithRawResponse:
        return AsyncShowtimesResourceWithRawResponse(self._by_vendor_venue_id.showtimes)


class ByVendorVenueIDResourceWithStreamingResponse:
    def __init__(self, by_vendor_venue_id: ByVendorVenueIDResource) -> None:
        self._by_vendor_venue_id = by_vendor_venue_id

        self.get = to_streamed_response_wrapper(
            by_vendor_venue_id.get,
        )

    @cached_property
    def showtimes(self) -> ShowtimesResourceWithStreamingResponse:
        return ShowtimesResourceWithStreamingResponse(self._by_vendor_venue_id.showtimes)


class AsyncByVendorVenueIDResourceWithStreamingResponse:
    def __init__(self, by_vendor_venue_id: AsyncByVendorVenueIDResource) -> None:
        self._by_vendor_venue_id = by_vendor_venue_id

        self.get = async_to_streamed_response_wrapper(
            by_vendor_venue_id.get,
        )

    @cached_property
    def showtimes(self) -> AsyncShowtimesResourceWithStreamingResponse:
        return AsyncShowtimesResourceWithStreamingResponse(self._by_vendor_venue_id.showtimes)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["ShowtimeResource", "AsyncShowtimeResource"]


class ShowtimeResource(SyncAPIResource):
    @cached_property
    def details(self) -> DetailsResource:
        return DetailsResource(self._client)

    @cached_property
    def with_raw_response(self) -> ShowtimeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return ShowtimeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ShowtimeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return ShowtimeResourceWithStreamingResponse(self)


class AsyncShowtimeResource(AsyncAPIResource):
    @cached_property
    def details(self) -> AsyncDetailsResource:
        return AsyncDetailsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncShowtimeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncShowtimeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncShowtimeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncShowtimeResourceWithStreamingResponse(self)


class ShowtimeResourceWithRawResponse:
    def __init__(self, showtime: ShowtimeResource) -> None:
        self._showtime = showtime

    @cached_property
    def details(self) -> DetailsResourceWithRawResponse:
        return DetailsResourceWithRawResponse(self._showtime.details)


class AsyncShowtimeResourceWithRawResponse:
    def __init__(self, showtime: AsyncShowtimeResource) -> None:
        self._showtime = showtime

    @cached_property
    def details(self) -> AsyncDetailsResourceWithRawResponse:
        return AsyncDetailsResourceWithRawResponse(self._showtime.details)


class ShowtimeResourceWithStreamingResponse:
    def __init__(self, showtime: ShowtimeResource) -> None:
        self._showtime = showtime

    @cached_property
    def details(self) -> DetailsResourceWithStreamingResponse:
        return DetailsResourceWithStreamingResponse(self._showtime.details)


class AsyncShowtimeResourceWithStreamingResponse:
    def __init__(self, showtime: AsyncShowtimeResource) -> None:
        self._showtime = showtime

    @cached_property
    def details(self) -> AsyncDetailsResourceWithStreamingResponse:
        return AsyncDetailsResourceWithStreamingResponse(self._showtime.details)



import json
from typing import Any, List, Union, cast
from typing_extensions import Annotated

import httpx
import pytest
import pydantic

from atom_tickets import BaseModel, AtomTickets, AsyncAtomTickets
from atom_tickets._response import (
    APIResponse,
    BaseAPIResponse,
    AsyncAPIResponse,
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    extract_response_type,
)
from atom_tickets._streaming import Stream
from atom_tickets._base_client import FinalRequestOptions


class ConcreteBaseAPIResponse(APIResponse[bytes]): ...


class ConcreteAPIResponse(APIResponse[List[str]]): ...


class ConcreteAsyncAPIResponse(APIResponse[httpx.Response]): ...


def test_extract_response_type_direct_classes() -> None:
    assert extract_response_type(BaseAPIResponse[str]) == str
    assert extract_response_type(APIResponse[str]) == str
    assert extract_response_type(AsyncAPIResponse[str]) == str


def test_extract_response_type_direct_class_missing_type_arg() -> None:
    with pytest.raises(
        RuntimeError,
        match="Expected type <class 'atom_tickets._response.AsyncAPIResponse'> to have a type argument at index 0 but it did not",
    ):
        extract_response_type(AsyncAPIResponse)


def test_extract_response_type_concrete_subclasses() -> None:
    assert extract_response_type(ConcreteBaseAPIResponse) == bytes
    assert extract_response_type(ConcreteAPIResponse) == List[str]
    assert extract_response_type(ConcreteAsyncAPIResponse) == httpx.Response


def test_extract_response_type_binary_response() -> None:
    assert extract_response_type(BinaryAPIResponse) == bytes
    assert extract_response_type(AsyncBinaryAPIResponse) == bytes


class PydanticModel(pydantic.BaseModel): ...


def test_response_parse_mismatched_basemodel(client: AtomTickets) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=b"foo"),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    with pytest.raises(
        TypeError,
        match="Pydantic models must subclass our base model type, e.g. `from atom_tickets import BaseModel`",
    ):
        response.parse(to=PydanticModel)


@pytest.mark.asyncio
async def test_async_response_parse_mismatched_basemodel(async_client: AsyncAtomTickets) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=b"foo"),
        client=async_client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    with pytest.raises(
        TypeError,
        match="Pydantic models must subclass our base model type, e.g. `from atom_tickets import BaseModel`",
    ):
        await response.parse(to=PydanticModel)


def test_response_parse_custom_stream(client: AtomTickets) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=b"foo"),
        client=client,
        stream=True,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    stream = response.parse(to=Stream[int])
    assert stream._cast_to == int


@pytest.mark.asyncio
async def test_async_response_parse_custom_stream(async_client: AsyncAtomTickets) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=b"foo"),
        client=async_client,
        stream=True,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    stream = await response.parse(to=Stream[int])
    assert stream._cast_to == int


class CustomModel(BaseModel):
    foo: str
    bar: int


def test_response_parse_custom_model(client: AtomTickets) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=json.dumps({"foo": "hello!", "bar": 2})),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = response.parse(to=CustomModel)
    assert obj.foo == "hello!"
    assert obj.bar == 2


@pytest.mark.asyncio
async def test_async_response_parse_custom_model(async_client: AsyncAtomTickets) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=json.dumps({"foo": "hello!", "bar": 2})),
        client=async_client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = await response.parse(to=CustomModel)
    assert obj.foo == "hello!"
    assert obj.bar == 2


def test_response_parse_annotated_type(client: AtomTickets) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=json.dumps({"foo": "hello!", "bar": 2})),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = response.parse(
        to=cast("type[CustomModel]", Annotated[CustomModel, "random metadata"]),
    )
    assert obj.foo == "hello!"
    assert obj.bar == 2


async def test_async_response_parse_annotated_type(async_client: AsyncAtomTickets) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=json.dumps({"foo": "hello!", "bar": 2})),
        client=async_client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = await response.parse(
        to=cast("type[CustomModel]", Annotated[CustomModel, "random metadata"]),
    )
    assert obj.foo == "hello!"
    assert obj.bar == 2


@pytest.mark.parametrize(
    "content, expected",
    [
        ("false", False),
        ("true", True),
        ("False", False),
        ("True", True),
        ("TrUe", True),
        ("FalSe", False),
    ],
)
def test_response_parse_bool(client: AtomTickets, content: str, expected: bool) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=content),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    result = response.parse(to=bool)
    assert result is expected


@pytest.mark.parametrize(
    "content, expected",
    [
        ("false", False),
        ("true", True),
        ("False", False),
        ("True", True),
        ("TrUe", True),
        ("FalSe", False),
    ],
)
async def test_async_response_parse_bool(client: AsyncAtomTickets, content: str, expected: bool) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=content),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    result = await response.parse(to=bool)
    assert result is expected


class OtherModel(BaseModel):
    a: str


@pytest.mark.parametrize("client", [False], indirect=True)  # loose validation
def test_response_parse_expect_model_union_non_json_content(client: AtomTickets) -> None:
    response = APIResponse(
        raw=httpx.Response(200, content=b"foo", headers={"Content-Type": "application/text"}),
        client=client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = response.parse(to=cast(Any, Union[CustomModel, OtherModel]))
    assert isinstance(obj, str)
    assert obj == "foo"


@pytest.mark.asyncio
@pytest.mark.parametrize("async_client", [False], indirect=True)  # loose validation
async def test_async_response_parse_expect_model_union_non_json_content(async_client: AsyncAtomTickets) -> None:
    response = AsyncAPIResponse(
        raw=httpx.Response(200, content=b"foo", headers={"Content-Type": "application/text"}),
        client=async_client,
        stream=False,
        stream_cls=None,
        cast_to=str,
        options=FinalRequestOptions.construct(method="get", url="/foo"),
    )

    obj = await response.parse(to=cast(Any, Union[CustomModel, OtherModel]))
    assert isinstance(obj, str)
    assert obj == "foo"



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .page_info import PageInfo as PageInfo
from .venue_details import VenueDetails as VenueDetails
from .detail_search_params import DetailSearchParams as DetailSearchParams
from .detail_get_by_ids_params import DetailGetByIDsParams as DetailGetByIDsParams
from .detail_get_by_location_params import DetailGetByLocationParams as DetailGetByLocationParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .venue import (
    VenueResource,
    AsyncVenueResource,
    VenueResourceWithRawResponse,
    AsyncVenueResourceWithRawResponse,
    VenueResourceWithStreamingResponse,
    AsyncVenueResourceWithStreamingResponse,
)
from .showtime import (
    ShowtimeResource,
    AsyncShowtimeResource,
    ShowtimeResourceWithRawResponse,
    AsyncShowtimeResourceWithRawResponse,
    ShowtimeResourceWithStreamingResponse,
    AsyncShowtimeResourceWithStreamingResponse,
)
from .production import (
    ProductionResource,
    AsyncProductionResource,
    ProductionResourceWithRawResponse,
    AsyncProductionResourceWithRawResponse,
    ProductionResourceWithStreamingResponse,
    AsyncProductionResourceWithStreamingResponse,
)

__all__ = [
    "ShowtimeResource",
    "AsyncShowtimeResource",
    "ShowtimeResourceWithRawResponse",
    "AsyncShowtimeResourceWithRawResponse",
    "ShowtimeResourceWithStreamingResponse",
    "AsyncShowtimeResourceWithStreamingResponse",
    "VenueResource",
    "AsyncVenueResource",
    "VenueResourceWithRawResponse",
    "AsyncVenueResourceWithRawResponse",
    "VenueResourceWithStreamingResponse",
    "AsyncVenueResourceWithStreamingResponse",
    "ProductionResource",
    "AsyncProductionResource",
    "ProductionResourceWithRawResponse",
    "AsyncProductionResourceWithRawResponse",
    "ProductionResourceWithStreamingResponse",
    "AsyncProductionResourceWithStreamingResponse",
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ......_types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.partner.v1.showtime.showtime_details import ShowtimeDetails

__all__ = ["ShowtimesResource", "AsyncShowtimesResource"]


class ShowtimesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ShowtimesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return ShowtimesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ShowtimesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return ShowtimesResourceWithStreamingResponse(self)

    def get_by_vendor_showtime_id(
        self,
        vendor_showtime_id: str,
        *,
        vendor_venue_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ShowtimeDetails:
        """
        Returns showtime details for a vendor-specific venue and showtime ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_venue_id:
            raise ValueError(f"Expected a non-empty value for `vendor_venue_id` but received {vendor_venue_id!r}")
        if not vendor_showtime_id:
            raise ValueError(f"Expected a non-empty value for `vendor_showtime_id` but received {vendor_showtime_id!r}")
        return self._get(
            f"/partner/v1/venues/byVendorVenueId/{vendor_venue_id}/showtimes/byVendorShowtimeId/{vendor_showtime_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ShowtimeDetails,
        )


class AsyncShowtimesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncShowtimesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncShowtimesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncShowtimesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncShowtimesResourceWithStreamingResponse(self)

    async def get_by_vendor_showtime_id(
        self,
        vendor_showtime_id: str,
        *,
        vendor_venue_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ShowtimeDetails:
        """
        Returns showtime details for a vendor-specific venue and showtime ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vendor_venue_id:
            raise ValueError(f"Expected a non-empty value for `vendor_venue_id` but received {vendor_venue_id!r}")
        if not vendor_showtime_id:
            raise ValueError(f"Expected a non-empty value for `vendor_showtime_id` but received {vendor_showtime_id!r}")
        return await self._get(
            f"/partner/v1/venues/byVendorVenueId/{vendor_venue_id}/showtimes/byVendorShowtimeId/{vendor_showtime_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ShowtimeDetails,
        )


class ShowtimesResourceWithRawResponse:
    def __init__(self, showtimes: ShowtimesResource) -> None:
        self._showtimes = showtimes

        self.get_by_vendor_showtime_id = to_raw_response_wrapper(
            showtimes.get_by_vendor_showtime_id,
        )


class AsyncShowtimesResourceWithRawResponse:
    def __init__(self, showtimes: AsyncShowtimesResource) -> None:
        self._showtimes = showtimes

        self.get_by_vendor_showtime_id = async_to_raw_response_wrapper(
            showtimes.get_by_vendor_showtime_id,
        )


class ShowtimesResourceWithStreamingResponse:
    def __init__(self, showtimes: ShowtimesResource) -> None:
        self._showtimes = showtimes

        self.get_by_vendor_showtime_id = to_streamed_response_wrapper(
            showtimes.get_by_vendor_showtime_id,
        )


class AsyncShowtimesResourceWithStreamingResponse:
    def __init__(self, showtimes: AsyncShowtimesResource) -> None:
        self._showtimes = showtimes

        self.get_by_vendor_showtime_id = async_to_streamed_response_wrapper(
            showtimes.get_by_vendor_showtime_id,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from .showtime import (
    ShowtimeResource,
    AsyncShowtimeResource,
    ShowtimeResourceWithRawResponse,
    AsyncShowtimeResourceWithRawResponse,
    ShowtimeResourceWithStreamingResponse,
    AsyncShowtimeResourceWithStreamingResponse,
)

__all__ = [
    "DetailsResource",
    "AsyncDetailsResource",
    "DetailsResourceWithRawResponse",
    "AsyncDetailsResourceWithRawResponse",
    "DetailsResourceWithStreamingResponse",
    "AsyncDetailsResourceWithStreamingResponse",
    "ShowtimeResource",
    "AsyncShowtimeResource",
    "ShowtimeResourceWithRawResponse",
    "AsyncShowtimeResourceWithRawResponse",
    "ShowtimeResourceWithStreamingResponse",
    "AsyncShowtimeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["DetailGetForMultipleVenuesParams", "ISODateBounds", "LocalDateBounds"]


class DetailGetForMultipleVenuesParams(TypedDict, total=False):
    venue_ids: Required[Annotated[List[str], PropertyInfo(alias="venueIds")]]
    """Set of venue IDs to retrieve showtimes for"""

    include_production_details: Annotated[Optional[bool], PropertyInfo(alias="includeProductionDetails")]
    """Whether to include production details in response"""

    iso_date_bounds: Annotated[Optional[ISODateBounds], PropertyInfo(alias="isoDateBounds")]
    """Date bounds in ISO format"""

    local_date_bounds: Annotated[Optional[LocalDateBounds], PropertyInfo(alias="localDateBounds")]
    """Date bounds in local format"""

    marketplace_id: Annotated[Optional[str], PropertyInfo(alias="marketplaceId")]
    """Marketplace identifier"""

    production_ids: Annotated[Optional[List[str]], PropertyInfo(alias="productionIds")]
    """Set of production IDs to filter showtimes by"""


class ISODateBounds(TypedDict, total=False):
    iso_end_date: Annotated[Union[str, datetime], PropertyInfo(alias="isoEndDate", format="iso8601")]
    """ISO8601 formatted end date without milliseconds"""

    iso_start_date: Annotated[Union[str, datetime], PropertyInfo(alias="isoStartDate", format="iso8601")]
    """ISO8601 formatted start date without milliseconds"""


class LocalDateBounds(TypedDict, total=False):
    local_end_date: Annotated[str, PropertyInfo(alias="localEndDate")]
    """Local end date in format YYYY-MM-DDTHH:MM:SS (no timezone)"""

    local_start_date: Annotated[str, PropertyInfo(alias="localStartDate")]
    """Local start date in format YYYY-MM-DDTHH:MM:SS (no timezone)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .showtimes import (
    ShowtimesResource,
    AsyncShowtimesResource,
    ShowtimesResourceWithRawResponse,
    AsyncShowtimesResourceWithRawResponse,
    ShowtimesResourceWithStreamingResponse,
    AsyncShowtimesResourceWithStreamingResponse,
)
from .by_vendor_venue_id import (
    ByVendorVenueIDResource,
    AsyncByVendorVenueIDResource,
    ByVendorVenueIDResourceWithRawResponse,
    AsyncByVendorVenueIDResourceWithRawResponse,
    ByVendorVenueIDResourceWithStreamingResponse,
    AsyncByVendorVenueIDResourceWithStreamingResponse,
)

__all__ = [
    "ShowtimesResource",
    "AsyncShowtimesResource",
    "ShowtimesResourceWithRawResponse",
    "AsyncShowtimesResourceWithRawResponse",
    "ShowtimesResourceWithStreamingResponse",
    "AsyncShowtimesResourceWithStreamingResponse",
    "ByVendorVenueIDResource",
    "AsyncByVendorVenueIDResource",
    "ByVendorVenueIDResourceWithRawResponse",
    "AsyncByVendorVenueIDResourceWithRawResponse",
    "ByVendorVenueIDResourceWithStreamingResponse",
    "AsyncByVendorVenueIDResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .page_info import PageInfo
from ....._models import BaseModel

__all__ = ["VenueDetails", "VenueDetail", "VenueDetailVenue", "VenueDetailVenueAddress", "VenueDetailVenueProperties"]


class VenueDetailVenueAddress(BaseModel):
    city: Optional[str] = None
    """City name"""

    lat: Optional[float] = None
    """Latitude coordinate"""

    line: Optional[str] = None
    """Street address line"""

    lon: Optional[float] = None
    """Longitude coordinate"""

    postal: Optional[str] = None
    """Postal code"""

    state: Optional[str] = None
    """State abbreviation"""


class VenueDetailVenueProperties(BaseModel):
    supported: Optional[bool] = None
    """Whether venue is supported by Atom Tickets"""

    supports_concessions: Optional[bool] = FieldInfo(alias="supportsConcessions", default=None)
    """Whether venue supports concessions"""


class VenueDetailVenue(BaseModel):
    id: Optional[str] = None
    """Venue identifier"""

    address: Optional[VenueDetailVenueAddress] = None

    atom_venue_id: Optional[str] = FieldInfo(alias="atomVenueId", default=None)
    """Atom Tickets internal venue ID"""

    name: Optional[str] = None
    """Venue name"""

    properties: Optional[VenueDetailVenueProperties] = None

    venue_url: Optional[str] = FieldInfo(alias="venueUrl", default=None)
    """URL to venue page on Atom Tickets"""


class VenueDetail(BaseModel):
    km_distance: Optional[float] = FieldInfo(alias="kmDistance", default=None)
    """Distance from specified location in kilometers"""

    venue: Optional[VenueDetailVenue] = None


class VenueDetails(BaseModel):
    page_info: Optional[PageInfo] = FieldInfo(alias="pageInfo", default=None)

    venue_details: Optional[List[VenueDetail]] = FieldInfo(alias="venueDetails", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["IDGetByVenueParams"]


class IDGetByVenueParams(TypedDict, total=False):
    iso_end_date: Required[Annotated[Union[str, datetime], PropertyInfo(alias="isoEndDate", format="iso8601")]]
    """ISO8601 formatted end date without milliseconds"""

    iso_start_date: Required[Annotated[Union[str, datetime], PropertyInfo(alias="isoStartDate", format="iso8601")]]
    """ISO8601 formatted start date without milliseconds"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from atom_tickets import AtomTickets, AsyncAtomTickets
from atom_tickets.types.partner.v1.production import ProductionDetails

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDetails:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_ids(self, client: AtomTickets) -> None:
        detail = client.partner.v1.production.details.get_by_ids(
            ids=["B00809994585"],
        )
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_ids_with_all_params(self, client: AtomTickets) -> None:
        detail = client.partner.v1.production.details.get_by_ids(
            ids=["B00809994585"],
            marketplace_id="marketplaceId",
            page=0,
            page_size=0,
        )
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_by_ids(self, client: AtomTickets) -> None:
        response = client.partner.v1.production.details.with_raw_response.get_by_ids(
            ids=["B00809994585"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = response.parse()
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_by_ids(self, client: AtomTickets) -> None:
        with client.partner.v1.production.details.with_streaming_response.get_by_ids(
            ids=["B00809994585"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = response.parse()
            assert_matches_type(ProductionDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDetails:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.production.details.get_by_ids(
            ids=["B00809994585"],
        )
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_ids_with_all_params(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.production.details.get_by_ids(
            ids=["B00809994585"],
            marketplace_id="marketplaceId",
            page=0,
            page_size=0,
        )
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        response = await async_client.partner.v1.production.details.with_raw_response.get_by_ids(
            ids=["B00809994585"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = await response.parse()
        assert_matches_type(ProductionDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        async with async_client.partner.v1.production.details.with_streaming_response.get_by_ids(
            ids=["B00809994585"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = await response.parse()
            assert_matches_type(ProductionDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from .showtimes import (
    ShowtimesResource,
    AsyncShowtimesResource,
    ShowtimesResourceWithRawResponse,
    AsyncShowtimesResourceWithRawResponse,
    ShowtimesResourceWithStreamingResponse,
    AsyncShowtimesResourceWithStreamingResponse,
)
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from .by_vendor_venue_id.by_vendor_venue_id import (
    ByVendorVenueIDResource,
    AsyncByVendorVenueIDResource,
    ByVendorVenueIDResourceWithRawResponse,
    AsyncByVendorVenueIDResourceWithRawResponse,
    ByVendorVenueIDResourceWithStreamingResponse,
    AsyncByVendorVenueIDResourceWithStreamingResponse,
)

__all__ = ["VenueResource", "AsyncVenueResource"]


class VenueResource(SyncAPIResource):
    @cached_property
    def details(self) -> DetailsResource:
        return DetailsResource(self._client)

    @cached_property
    def by_vendor_venue_id(self) -> ByVendorVenueIDResource:
        return ByVendorVenueIDResource(self._client)

    @cached_property
    def showtimes(self) -> ShowtimesResource:
        return ShowtimesResource(self._client)

    @cached_property
    def with_raw_response(self) -> VenueResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return VenueResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VenueResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return VenueResourceWithStreamingResponse(self)


class AsyncVenueResource(AsyncAPIResource):
    @cached_property
    def details(self) -> AsyncDetailsResource:
        return AsyncDetailsResource(self._client)

    @cached_property
    def by_vendor_venue_id(self) -> AsyncByVendorVenueIDResource:
        return AsyncByVendorVenueIDResource(self._client)

    @cached_property
    def showtimes(self) -> AsyncShowtimesResource:
        return AsyncShowtimesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncVenueResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncVenueResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVenueResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncVenueResourceWithStreamingResponse(self)


class VenueResourceWithRawResponse:
    def __init__(self, venue: VenueResource) -> None:
        self._venue = venue

    @cached_property
    def details(self) -> DetailsResourceWithRawResponse:
        return DetailsResourceWithRawResponse(self._venue.details)

    @cached_property
    def by_vendor_venue_id(self) -> ByVendorVenueIDResourceWithRawResponse:
        return ByVendorVenueIDResourceWithRawResponse(self._venue.by_vendor_venue_id)

    @cached_property
    def showtimes(self) -> ShowtimesResourceWithRawResponse:
        return ShowtimesResourceWithRawResponse(self._venue.showtimes)


class AsyncVenueResourceWithRawResponse:
    def __init__(self, venue: AsyncVenueResource) -> None:
        self._venue = venue

    @cached_property
    def details(self) -> AsyncDetailsResourceWithRawResponse:
        return AsyncDetailsResourceWithRawResponse(self._venue.details)

    @cached_property
    def by_vendor_venue_id(self) -> AsyncByVendorVenueIDResourceWithRawResponse:
        return AsyncByVendorVenueIDResourceWithRawResponse(self._venue.by_vendor_venue_id)

    @cached_property
    def showtimes(self) -> AsyncShowtimesResourceWithRawResponse:
        return AsyncShowtimesResourceWithRawResponse(self._venue.showtimes)


class VenueResourceWithStreamingResponse:
    def __init__(self, venue: VenueResource) -> None:
        self._venue = venue

    @cached_property
    def details(self) -> DetailsResourceWithStreamingResponse:
        return DetailsResourceWithStreamingResponse(self._venue.details)

    @cached_property
    def by_vendor_venue_id(self) -> ByVendorVenueIDResourceWithStreamingResponse:
        return ByVendorVenueIDResourceWithStreamingResponse(self._venue.by_vendor_venue_id)

    @cached_property
    def showtimes(self) -> ShowtimesResourceWithStreamingResponse:
        return ShowtimesResourceWithStreamingResponse(self._venue.showtimes)


class AsyncVenueResourceWithStreamingResponse:
    def __init__(self, venue: AsyncVenueResource) -> None:
        self._venue = venue

    @cached_property
    def details(self) -> AsyncDetailsResourceWithStreamingResponse:
        return AsyncDetailsResourceWithStreamingResponse(self._venue.details)

    @cached_property
    def by_vendor_venue_id(self) -> AsyncByVendorVenueIDResourceWithStreamingResponse:
        return AsyncByVendorVenueIDResourceWithStreamingResponse(self._venue.by_vendor_venue_id)

    @cached_property
    def showtimes(self) -> AsyncShowtimesResourceWithStreamingResponse:
        return AsyncShowtimesResourceWithStreamingResponse(self._venue.showtimes)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["DetailGetByIDsParams"]


class DetailGetByIDsParams(TypedDict, total=False):
    ids: Required[List[str]]
    """List of production IDs to retrieve"""

    marketplace_id: Annotated[Optional[str], PropertyInfo(alias="marketplaceId")]
    """Marketplace identifier (US by default)"""

    page: Optional[int]
    """Page number for results"""

    page_size: Annotated[Optional[int], PropertyInfo(alias="pageSize")]
    """Number of results per page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime

import httpx

from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.partner.v1.production import id_get_by_venue_params
from .....types.partner.v1.production.id_get_by_venue_response import IDGetByVenueResponse

__all__ = ["IDsResource", "AsyncIDsResource"]


class IDsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IDsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return IDsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IDsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return IDsResourceWithStreamingResponse(self)

    def get_by_venue(
        self,
        venue_id: str,
        *,
        iso_end_date: Union[str, datetime],
        iso_start_date: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IDGetByVenueResponse:
        """
        Returns production IDs available at a specified venue

        Args:
          iso_end_date: ISO8601 formatted end date without milliseconds

          iso_start_date: ISO8601 formatted start date without milliseconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not venue_id:
            raise ValueError(f"Expected a non-empty value for `venue_id` but received {venue_id!r}")
        return self._get(
            f"/partner/v1/production/ids/byVenue/{venue_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "iso_end_date": iso_end_date,
                        "iso_start_date": iso_start_date,
                    },
                    id_get_by_venue_params.IDGetByVenueParams,
                ),
            ),
            cast_to=IDGetByVenueResponse,
        )


class AsyncIDsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIDsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncIDsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIDsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncIDsResourceWithStreamingResponse(self)

    async def get_by_venue(
        self,
        venue_id: str,
        *,
        iso_end_date: Union[str, datetime],
        iso_start_date: Union[str, datetime],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IDGetByVenueResponse:
        """
        Returns production IDs available at a specified venue

        Args:
          iso_end_date: ISO8601 formatted end date without milliseconds

          iso_start_date: ISO8601 formatted start date without milliseconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not venue_id:
            raise ValueError(f"Expected a non-empty value for `venue_id` but received {venue_id!r}")
        return await self._get(
            f"/partner/v1/production/ids/byVenue/{venue_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "iso_end_date": iso_end_date,
                        "iso_start_date": iso_start_date,
                    },
                    id_get_by_venue_params.IDGetByVenueParams,
                ),
            ),
            cast_to=IDGetByVenueResponse,
        )


class IDsResourceWithRawResponse:
    def __init__(self, ids: IDsResource) -> None:
        self._ids = ids

        self.get_by_venue = to_raw_response_wrapper(
            ids.get_by_venue,
        )


class AsyncIDsResourceWithRawResponse:
    def __init__(self, ids: AsyncIDsResource) -> None:
        self._ids = ids

        self.get_by_venue = async_to_raw_response_wrapper(
            ids.get_by_venue,
        )


class IDsResourceWithStreamingResponse:
    def __init__(self, ids: IDsResource) -> None:
        self._ids = ids

        self.get_by_venue = to_streamed_response_wrapper(
            ids.get_by_venue,
        )


class AsyncIDsResourceWithStreamingResponse:
    def __init__(self, ids: AsyncIDsResource) -> None:
        self._ids = ids

        self.get_by_venue = async_to_streamed_response_wrapper(
            ids.get_by_venue,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from atom_tickets import AtomTickets, AsyncAtomTickets
from atom_tickets.types.partner.v1.production import ProductionDetails

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProduction:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_vendor_production_id(self, client: AtomTickets) -> None:
        production = client.partner.v1.production.get_by_vendor_production_id(
            "vendorProductionId",
        )
        assert_matches_type(ProductionDetails, production, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_by_vendor_production_id(self, client: AtomTickets) -> None:
        response = client.partner.v1.production.with_raw_response.get_by_vendor_production_id(
            "vendorProductionId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        production = response.parse()
        assert_matches_type(ProductionDetails, production, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_by_vendor_production_id(self, client: AtomTickets) -> None:
        with client.partner.v1.production.with_streaming_response.get_by_vendor_production_id(
            "vendorProductionId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            production = response.parse()
            assert_matches_type(ProductionDetails, production, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_get_by_vendor_production_id(self, client: AtomTickets) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `vendor_production_id` but received ''"):
            client.partner.v1.production.with_raw_response.get_by_vendor_production_id(
                "",
            )


class TestAsyncProduction:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_vendor_production_id(self, async_client: AsyncAtomTickets) -> None:
        production = await async_client.partner.v1.production.get_by_vendor_production_id(
            "vendorProductionId",
        )
        assert_matches_type(ProductionDetails, production, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_by_vendor_production_id(self, async_client: AsyncAtomTickets) -> None:
        response = await async_client.partner.v1.production.with_raw_response.get_by_vendor_production_id(
            "vendorProductionId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        production = await response.parse()
        assert_matches_type(ProductionDetails, production, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_by_vendor_production_id(self, async_client: AsyncAtomTickets) -> None:
        async with async_client.partner.v1.production.with_streaming_response.get_by_vendor_production_id(
            "vendorProductionId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            production = await response.parse()
            assert_matches_type(ProductionDetails, production, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_get_by_vendor_production_id(self, async_client: AsyncAtomTickets) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `vendor_production_id` but received ''"):
            await async_client.partner.v1.production.with_raw_response.get_by_vendor_production_id(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["PageInfo"]


class PageInfo(BaseModel):
    page: Optional[int] = None
    """Current page number"""

    page_size: Optional[int] = FieldInfo(alias="pageSize", default=None)
    """Number of items per page"""

    total_pages: Optional[int] = FieldInfo(alias="totalPages", default=None)
    """Total number of pages available"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ids import (
    IDsResource,
    AsyncIDsResource,
    IDsResourceWithRawResponse,
    AsyncIDsResourceWithRawResponse,
    IDsResourceWithStreamingResponse,
    AsyncIDsResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from .production import (
    ProductionResource,
    AsyncProductionResource,
    ProductionResourceWithRawResponse,
    AsyncProductionResourceWithRawResponse,
    ProductionResourceWithStreamingResponse,
    AsyncProductionResourceWithStreamingResponse,
)

__all__ = [
    "IDsResource",
    "AsyncIDsResource",
    "IDsResourceWithRawResponse",
    "AsyncIDsResourceWithRawResponse",
    "IDsResourceWithStreamingResponse",
    "AsyncIDsResourceWithStreamingResponse",
    "DetailsResource",
    "AsyncDetailsResource",
    "DetailsResourceWithRawResponse",
    "AsyncDetailsResourceWithRawResponse",
    "DetailsResourceWithStreamingResponse",
    "AsyncDetailsResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "ProductionResource",
    "AsyncProductionResource",
    "ProductionResourceWithRawResponse",
    "AsyncProductionResourceWithRawResponse",
    "ProductionResourceWithStreamingResponse",
    "AsyncProductionResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["DetailGetByIDsParams", "Location"]


class DetailGetByIDsParams(TypedDict, total=False):
    ids: Required[List[str]]
    """List of venue IDs to retrieve"""

    location: Optional[Location]
    """Location to calculate distance from"""

    page: Optional[int]
    """Page number for results"""

    page_size: Annotated[Optional[int], PropertyInfo(alias="pageSize")]
    """Number of results per page"""


class Location(TypedDict, total=False):
    lat: float
    """Latitude coordinate"""

    lon: float
    """Longitude coordinate"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ....._models import BaseModel

__all__ = ["IDGetByVenueResponse"]


class IDGetByVenueResponse(BaseModel):
    ids: Optional[List[str]] = None
    """List of production IDs"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ...._compat import cached_property
from .venue.venue import (
    VenueResource,
    AsyncVenueResource,
    VenueResourceWithRawResponse,
    AsyncVenueResourceWithRawResponse,
    VenueResourceWithStreamingResponse,
    AsyncVenueResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource
from .showtime.showtime import (
    ShowtimeResource,
    AsyncShowtimeResource,
    ShowtimeResourceWithRawResponse,
    AsyncShowtimeResourceWithRawResponse,
    ShowtimeResourceWithStreamingResponse,
    AsyncShowtimeResourceWithStreamingResponse,
)
from .production.production import (
    ProductionResource,
    AsyncProductionResource,
    ProductionResourceWithRawResponse,
    AsyncProductionResourceWithRawResponse,
    ProductionResourceWithStreamingResponse,
    AsyncProductionResourceWithStreamingResponse,
)

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def showtime(self) -> ShowtimeResource:
        return ShowtimeResource(self._client)

    @cached_property
    def venue(self) -> VenueResource:
        return VenueResource(self._client)

    @cached_property
    def production(self) -> ProductionResource:
        return ProductionResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def showtime(self) -> AsyncShowtimeResource:
        return AsyncShowtimeResource(self._client)

    @cached_property
    def venue(self) -> AsyncVenueResource:
        return AsyncVenueResource(self._client)

    @cached_property
    def production(self) -> AsyncProductionResource:
        return AsyncProductionResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

    @cached_property
    def showtime(self) -> ShowtimeResourceWithRawResponse:
        return ShowtimeResourceWithRawResponse(self._v1.showtime)

    @cached_property
    def venue(self) -> VenueResourceWithRawResponse:
        return VenueResourceWithRawResponse(self._v1.venue)

    @cached_property
    def production(self) -> ProductionResourceWithRawResponse:
        return ProductionResourceWithRawResponse(self._v1.production)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

    @cached_property
    def showtime(self) -> AsyncShowtimeResourceWithRawResponse:
        return AsyncShowtimeResourceWithRawResponse(self._v1.showtime)

    @cached_property
    def venue(self) -> AsyncVenueResourceWithRawResponse:
        return AsyncVenueResourceWithRawResponse(self._v1.venue)

    @cached_property
    def production(self) -> AsyncProductionResourceWithRawResponse:
        return AsyncProductionResourceWithRawResponse(self._v1.production)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

    @cached_property
    def showtime(self) -> ShowtimeResourceWithStreamingResponse:
        return ShowtimeResourceWithStreamingResponse(self._v1.showtime)

    @cached_property
    def venue(self) -> VenueResourceWithStreamingResponse:
        return VenueResourceWithStreamingResponse(self._v1.venue)

    @cached_property
    def production(self) -> ProductionResourceWithStreamingResponse:
        return ProductionResourceWithStreamingResponse(self._v1.production)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

    @cached_property
    def showtime(self) -> AsyncShowtimeResourceWithStreamingResponse:
        return AsyncShowtimeResourceWithStreamingResponse(self._v1.showtime)

    @cached_property
    def venue(self) -> AsyncVenueResourceWithStreamingResponse:
        return AsyncVenueResourceWithStreamingResponse(self._v1.venue)

    @cached_property
    def production(self) -> AsyncProductionResourceWithStreamingResponse:
        return AsyncProductionResourceWithStreamingResponse(self._v1.production)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ....._models import BaseModel
from ..venue.page_info import PageInfo

__all__ = [
    "ProductionDetails",
    "ProductionDetail",
    "ProductionDetailContributors",
    "ProductionDetailContributorsCast",
    "ProductionDetailContributorsCrew",
    "ProductionDetailProductionMedia",
    "ProductionDetailProductionMediaImageData",
    "ProductionDetailProductionMediaTrailerData",
]


class ProductionDetailContributorsCast(BaseModel):
    character_name: Optional[str] = FieldInfo(alias="characterName", default=None)
    """Character name"""

    name: Optional[str] = None
    """Actor name"""


class ProductionDetailContributorsCrew(BaseModel):
    name: Optional[str] = None
    """Crew member name"""

    role: Optional[str] = None
    """Crew member role"""


class ProductionDetailContributors(BaseModel):
    cast: Optional[List[ProductionDetailContributorsCast]] = None
    """List of cast members"""

    crew: Optional[List[ProductionDetailContributorsCrew]] = None
    """List of crew members"""


class ProductionDetailProductionMediaImageData(BaseModel):
    cover_image_url: Optional[str] = FieldInfo(alias="coverImageUrl", default=None)
    """URL to cover image"""

    promo_image_urls: Optional[List[str]] = FieldInfo(alias="promoImageUrls", default=None)
    """URLs to promotional images"""


class ProductionDetailProductionMediaTrailerData(BaseModel):
    trailer_urls: Optional[List[str]] = FieldInfo(alias="trailerUrls", default=None)
    """URLs to trailer videos"""


class ProductionDetailProductionMedia(BaseModel):
    image_data: Optional[ProductionDetailProductionMediaImageData] = FieldInfo(alias="imageData", default=None)

    trailer_data: Optional[ProductionDetailProductionMediaTrailerData] = FieldInfo(alias="trailerData", default=None)


class ProductionDetail(BaseModel):
    id: Optional[str] = None
    """Production identifier"""

    advisory_rating: Optional[str] = FieldInfo(alias="advisoryRating", default=None)
    """Advisory rating (PG, PG-13, R, etc.)"""

    atom_production_id: Optional[str] = FieldInfo(alias="atomProductionId", default=None)
    """Atom Tickets internal production ID"""

    atom_user_score: Optional[float] = FieldInfo(alias="atomUserScore", default=None)
    """User score on Atom Tickets"""

    contributors: Optional[ProductionDetailContributors] = None

    distributor: Optional[str] = None
    """Distributor name"""

    genres: Optional[List[str]] = None
    """List of genres"""

    imdb_id: Optional[str] = FieldInfo(alias="imdbId", default=None)
    """IMDB identifier"""

    name: Optional[str] = None
    """Production name"""

    production_media: Optional[ProductionDetailProductionMedia] = FieldInfo(alias="productionMedia", default=None)

    production_url: Optional[str] = FieldInfo(alias="productionUrl", default=None)
    """URL to production page on Atom Tickets"""

    release_date: Optional[str] = FieldInfo(alias="releaseDate", default=None)
    """Release date in format YYYY-MM-DD"""

    runtime_minutes: Optional[int] = FieldInfo(alias="runtimeMinutes", default=None)
    """Runtime in minutes"""

    synopsis: Optional[str] = None
    """Production synopsis"""


class ProductionDetails(BaseModel):
    page_info: Optional[PageInfo] = FieldInfo(alias="pageInfo", default=None)

    production_details: Optional[List[ProductionDetail]] = FieldInfo(alias="productionDetails", default=None)



from atom_tickets._utils import deepcopy_minimal


def assert_different_identities(obj1: object, obj2: object) -> None:
    assert obj1 == obj2
    assert id(obj1) != id(obj2)


def test_simple_dict() -> None:
    obj1 = {"foo": "bar"}
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)


def test_nested_dict() -> None:
    obj1 = {"foo": {"bar": True}}
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)
    assert_different_identities(obj1["foo"], obj2["foo"])


def test_complex_nested_dict() -> None:
    obj1 = {"foo": {"bar": [{"hello": "world"}]}}
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)
    assert_different_identities(obj1["foo"], obj2["foo"])
    assert_different_identities(obj1["foo"]["bar"], obj2["foo"]["bar"])
    assert_different_identities(obj1["foo"]["bar"][0], obj2["foo"]["bar"][0])


def test_simple_list() -> None:
    obj1 = ["a", "b", "c"]
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)


def test_nested_list() -> None:
    obj1 = ["a", [1, 2, 3]]
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)
    assert_different_identities(obj1[1], obj2[1])


class MyObject: ...


def test_ignores_other_types() -> None:
    # custom classes
    my_obj = MyObject()
    obj1 = {"foo": my_obj}
    obj2 = deepcopy_minimal(obj1)
    assert_different_identities(obj1, obj2)
    assert obj1["foo"] is my_obj

    # tuples
    obj3 = ("a", "b")
    obj4 = deepcopy_minimal(obj3)
    assert obj3 is obj4



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .venue import (
    VenueResource,
    AsyncVenueResource,
    VenueResourceWithRawResponse,
    AsyncVenueResourceWithRawResponse,
    VenueResourceWithStreamingResponse,
    AsyncVenueResourceWithStreamingResponse,
)
from .details import (
    DetailsResource,
    AsyncDetailsResource,
    DetailsResourceWithRawResponse,
    AsyncDetailsResourceWithRawResponse,
    DetailsResourceWithStreamingResponse,
    AsyncDetailsResourceWithStreamingResponse,
)
from .showtimes import (
    ShowtimesResource,
    AsyncShowtimesResource,
    ShowtimesResourceWithRawResponse,
    AsyncShowtimesResourceWithRawResponse,
    ShowtimesResourceWithStreamingResponse,
    AsyncShowtimesResourceWithStreamingResponse,
)
from .by_vendor_venue_id import (
    ByVendorVenueIDResource,
    AsyncByVendorVenueIDResource,
    ByVendorVenueIDResourceWithRawResponse,
    AsyncByVendorVenueIDResourceWithRawResponse,
    ByVendorVenueIDResourceWithStreamingResponse,
    AsyncByVendorVenueIDResourceWithStreamingResponse,
)

__all__ = [
    "DetailsResource",
    "AsyncDetailsResource",
    "DetailsResourceWithRawResponse",
    "AsyncDetailsResourceWithRawResponse",
    "DetailsResourceWithStreamingResponse",
    "AsyncDetailsResourceWithStreamingResponse",
    "ByVendorVenueIDResource",
    "AsyncByVendorVenueIDResource",
    "ByVendorVenueIDResourceWithRawResponse",
    "AsyncByVendorVenueIDResourceWithRawResponse",
    "ByVendorVenueIDResourceWithStreamingResponse",
    "AsyncByVendorVenueIDResourceWithStreamingResponse",
    "ShowtimesResource",
    "AsyncShowtimesResource",
    "ShowtimesResourceWithRawResponse",
    "AsyncShowtimesResourceWithRawResponse",
    "ShowtimesResourceWithStreamingResponse",
    "AsyncShowtimesResourceWithStreamingResponse",
    "VenueResource",
    "AsyncVenueResource",
    "VenueResourceWithRawResponse",
    "AsyncVenueResourceWithRawResponse",
    "VenueResourceWithStreamingResponse",
    "AsyncVenueResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SearchGetByNameParams"]


class SearchGetByNameParams(TypedDict, total=False):
    name: Required[str]
    """Production name to search for"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = [
    "ShowtimeDetails",
    "AttributeMap",
    "PreOrderDetail",
    "ShowtimeDetail",
    "ShowtimeDetailOfferData",
    "ShowtimeDetailOfferDataOffer",
    "ShowtimeDetailOfferDataOfferPrice",
]


class AttributeMap(BaseModel):
    id: Optional[str] = None
    """Attribute identifier"""

    description: Optional[str] = None
    """Attribute description"""

    friendly_name: Optional[str] = FieldInfo(alias="friendlyName", default=None)
    """User-friendly attribute name"""

    icon_url: Optional[str] = FieldInfo(alias="iconUrl", default=None)
    """URL to attribute icon"""

    type: Optional[str] = None
    """Attribute type"""


class PreOrderDetail(BaseModel):
    production_id: Optional[str] = FieldInfo(alias="productionId", default=None)
    """Production identifier"""

    showtime_days: Optional[List[str]] = FieldInfo(alias="showtimeDays", default=None)
    """List of days with showtimes available for pre-order"""

    venue_id: Optional[str] = FieldInfo(alias="venueId", default=None)
    """Venue identifier"""


class ShowtimeDetailOfferDataOfferPrice(BaseModel):
    currency_code: Optional[str] = FieldInfo(alias="currencyCode", default=None)
    """Currency code (e.g., USD)"""

    value: Optional[float] = None
    """Price value"""


class ShowtimeDetailOfferDataOffer(BaseModel):
    label: Optional[str] = None
    """Offer label (e.g., Matinee, Senior)"""

    price: Optional[ShowtimeDetailOfferDataOfferPrice] = None


class ShowtimeDetailOfferData(BaseModel):
    offers: Optional[List[ShowtimeDetailOfferDataOffer]] = None
    """List of price offers"""


class ShowtimeDetail(BaseModel):
    attributes: Optional[List[str]] = None
    """List of attribute keys for the attributeMap"""

    available_inventory: Optional[int] = FieldInfo(alias="availableInventory", default=None)
    """Number of available seats"""

    checkout_url: Optional[str] = FieldInfo(alias="checkoutUrl", default=None)
    """URL to checkout page on Atom Tickets"""

    local_showtime_start: Optional[datetime] = FieldInfo(alias="localShowtimeStart", default=None)
    """Local showtime start in ISO8601 format without milliseconds"""

    offer_data: Optional[ShowtimeDetailOfferData] = FieldInfo(alias="offerData", default=None)

    production_id: Optional[str] = FieldInfo(alias="productionId", default=None)
    """Production identifier"""

    showtime_id: Optional[str] = FieldInfo(alias="showtimeId", default=None)
    """Showtime identifier"""

    tags: Optional[List[str]] = None
    """Tags for special event showtimes"""

    utc_showtime_start: Optional[datetime] = FieldInfo(alias="utcShowtimeStart", default=None)
    """UTC showtime start in ISO8601 format without milliseconds"""

    venue_id: Optional[str] = FieldInfo(alias="venueId", default=None)
    """Venue identifier"""


class ShowtimeDetails(BaseModel):
    attribute_map: Optional[Dict[str, AttributeMap]] = FieldInfo(alias="attributeMap", default=None)
    """Map of attribute keys to attribute details"""

    pre_order_details: Optional[List[PreOrderDetail]] = FieldInfo(alias="preOrderDetails", default=None)

    showtime_details: Optional[List[ShowtimeDetail]] = FieldInfo(alias="showtimeDetails", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.partner.v1.production import detail_get_by_ids_params
from .....types.partner.v1.production.production_details import ProductionDetails

__all__ = ["DetailsResource", "AsyncDetailsResource"]


class DetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return DetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return DetailsResourceWithStreamingResponse(self)

    def get_by_ids(
        self,
        *,
        ids: List[str],
        marketplace_id: Optional[str] | NotGiven = NOT_GIVEN,
        page: Optional[int] | NotGiven = NOT_GIVEN,
        page_size: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProductionDetails:
        """
        Returns details for specified production IDs

        Args:
          ids: List of production IDs to retrieve

          marketplace_id: Marketplace identifier (US by default)

          page: Page number for results

          page_size: Number of results per page

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/partner/v1/production/details/byIds",
            body=maybe_transform(
                {
                    "ids": ids,
                    "marketplace_id": marketplace_id,
                    "page": page,
                    "page_size": page_size,
                },
                detail_get_by_ids_params.DetailGetByIDsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductionDetails,
        )


class AsyncDetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncDetailsResourceWithStreamingResponse(self)

    async def get_by_ids(
        self,
        *,
        ids: List[str],
        marketplace_id: Optional[str] | NotGiven = NOT_GIVEN,
        page: Optional[int] | NotGiven = NOT_GIVEN,
        page_size: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProductionDetails:
        """
        Returns details for specified production IDs

        Args:
          ids: List of production IDs to retrieve

          marketplace_id: Marketplace identifier (US by default)

          page: Page number for results

          page_size: Number of results per page

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/partner/v1/production/details/byIds",
            body=await async_maybe_transform(
                {
                    "ids": ids,
                    "marketplace_id": marketplace_id,
                    "page": page,
                    "page_size": page_size,
                },
                detail_get_by_ids_params.DetailGetByIDsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductionDetails,
        )


class DetailsResourceWithRawResponse:
    def __init__(self, details: DetailsResource) -> None:
        self._details = details

        self.get_by_ids = to_raw_response_wrapper(
            details.get_by_ids,
        )


class AsyncDetailsResourceWithRawResponse:
    def __init__(self, details: AsyncDetailsResource) -> None:
        self._details = details

        self.get_by_ids = async_to_raw_response_wrapper(
            details.get_by_ids,
        )


class DetailsResourceWithStreamingResponse:
    def __init__(self, details: DetailsResource) -> None:
        self._details = details

        self.get_by_ids = to_streamed_response_wrapper(
            details.get_by_ids,
        )


class AsyncDetailsResourceWithStreamingResponse:
    def __init__(self, details: AsyncDetailsResource) -> None:
        self._details = details

        self.get_by_ids = async_to_streamed_response_wrapper(
            details.get_by_ids,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .production_details import ProductionDetails as ProductionDetails
from .id_get_by_venue_params import IDGetByVenueParams as IDGetByVenueParams
from .detail_get_by_ids_params import DetailGetByIDsParams as DetailGetByIDsParams
from .id_get_by_venue_response import IDGetByVenueResponse as IDGetByVenueResponse
from .search_get_by_name_params import SearchGetByNameParams as SearchGetByNameParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .v1.v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["PartnerResource", "AsyncPartnerResource"]


class PartnerResource(SyncAPIResource):
    @cached_property
    def v1(self) -> V1Resource:
        return V1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> PartnerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return PartnerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PartnerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return PartnerResourceWithStreamingResponse(self)

    def ping(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Health check endpoint to validate API availability"""
        return self._get(
            "/partner/ping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncPartnerResource(AsyncAPIResource):
    @cached_property
    def v1(self) -> AsyncV1Resource:
        return AsyncV1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPartnerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AtomTickets/discovery-search#accessing-raw-response-data-eg-headers
        """
        return AsyncPartnerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPartnerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AtomTickets/discovery-search#with_streaming_response
        """
        return AsyncPartnerResourceWithStreamingResponse(self)

    async def ping(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Health check endpoint to validate API availability"""
        return await self._get(
            "/partner/ping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class PartnerResourceWithRawResponse:
    def __init__(self, partner: PartnerResource) -> None:
        self._partner = partner

        self.ping = to_raw_response_wrapper(
            partner.ping,
        )

    @cached_property
    def v1(self) -> V1ResourceWithRawResponse:
        return V1ResourceWithRawResponse(self._partner.v1)


class AsyncPartnerResourceWithRawResponse:
    def __init__(self, partner: AsyncPartnerResource) -> None:
        self._partner = partner

        self.ping = async_to_raw_response_wrapper(
            partner.ping,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithRawResponse:
        return AsyncV1ResourceWithRawResponse(self._partner.v1)


class PartnerResourceWithStreamingResponse:
    def __init__(self, partner: PartnerResource) -> None:
        self._partner = partner

        self.ping = to_streamed_response_wrapper(
            partner.ping,
        )

    @cached_property
    def v1(self) -> V1ResourceWithStreamingResponse:
        return V1ResourceWithStreamingResponse(self._partner.v1)


class AsyncPartnerResourceWithStreamingResponse:
    def __init__(self, partner: AsyncPartnerResource) -> None:
        self._partner = partner

        self.ping = async_to_streamed_response_wrapper(
            partner.ping,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithStreamingResponse:
        return AsyncV1ResourceWithStreamingResponse(self._partner.v1)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from atom_tickets import AtomTickets, AsyncAtomTickets
from atom_tickets._utils import parse_datetime
from atom_tickets.types.partner.v1.showtime import (
    ShowtimeDetails,
    DetailGetForMultipleVenuesResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDetails:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_ids(self, client: AtomTickets) -> None:
        detail = client.partner.v1.showtime.details.get_by_ids(
            ids=["D00747321039"],
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_ids_with_all_params(self, client: AtomTickets) -> None:
        detail = client.partner.v1.showtime.details.get_by_ids(
            ids=["D00747321039"],
            page=0,
            page_size=0,
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_by_ids(self, client: AtomTickets) -> None:
        response = client.partner.v1.showtime.details.with_raw_response.get_by_ids(
            ids=["D00747321039"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = response.parse()
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_by_ids(self, client: AtomTickets) -> None:
        with client.partner.v1.showtime.details.with_streaming_response.get_by_ids(
            ids=["D00747321039"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = response.parse()
            assert_matches_type(ShowtimeDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_venue(self, client: AtomTickets) -> None:
        detail = client.partner.v1.showtime.details.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_by_venue(self, client: AtomTickets) -> None:
        response = client.partner.v1.showtime.details.with_raw_response.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = response.parse()
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_by_venue(self, client: AtomTickets) -> None:
        with client.partner.v1.showtime.details.with_streaming_response.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = response.parse()
            assert_matches_type(ShowtimeDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_get_by_venue(self, client: AtomTickets) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `venue_id` but received ''"):
            client.partner.v1.showtime.details.with_raw_response.get_by_venue(
                venue_id="",
                iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
                iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_get_for_multiple_venues(self, client: AtomTickets) -> None:
        detail = client.partner.v1.showtime.details.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        )
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_for_multiple_venues_with_all_params(self, client: AtomTickets) -> None:
        detail = client.partner.v1.showtime.details.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
            include_production_details=True,
            iso_date_bounds={
                "iso_end_date": parse_datetime("2019-02-26T07:00:00Z"),
                "iso_start_date": parse_datetime("2019-02-25T07:00:00Z"),
            },
            local_date_bounds={
                "local_end_date": "localEndDate",
                "local_start_date": "localStartDate",
            },
            marketplace_id="marketplaceId",
            production_ids=["string"],
        )
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_for_multiple_venues(self, client: AtomTickets) -> None:
        response = client.partner.v1.showtime.details.with_raw_response.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = response.parse()
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_for_multiple_venues(self, client: AtomTickets) -> None:
        with client.partner.v1.showtime.details.with_streaming_response.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = response.parse()
            assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDetails:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.showtime.details.get_by_ids(
            ids=["D00747321039"],
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_ids_with_all_params(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.showtime.details.get_by_ids(
            ids=["D00747321039"],
            page=0,
            page_size=0,
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        response = await async_client.partner.v1.showtime.details.with_raw_response.get_by_ids(
            ids=["D00747321039"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = await response.parse()
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_by_ids(self, async_client: AsyncAtomTickets) -> None:
        async with async_client.partner.v1.showtime.details.with_streaming_response.get_by_ids(
            ids=["D00747321039"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = await response.parse()
            assert_matches_type(ShowtimeDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_venue(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.showtime.details.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_by_venue(self, async_client: AsyncAtomTickets) -> None:
        response = await async_client.partner.v1.showtime.details.with_raw_response.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = await response.parse()
        assert_matches_type(ShowtimeDetails, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_by_venue(self, async_client: AsyncAtomTickets) -> None:
        async with async_client.partner.v1.showtime.details.with_streaming_response.get_by_venue(
            venue_id="venueId",
            iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = await response.parse()
            assert_matches_type(ShowtimeDetails, detail, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_get_by_venue(self, async_client: AsyncAtomTickets) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `venue_id` but received ''"):
            await async_client.partner.v1.showtime.details.with_raw_response.get_by_venue(
                venue_id="",
                iso_end_date=parse_datetime("2019-12-27T18:11:19.117Z"),
                iso_start_date=parse_datetime("2019-12-27T18:11:19.117Z"),
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_for_multiple_venues(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.showtime.details.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        )
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_for_multiple_venues_with_all_params(self, async_client: AsyncAtomTickets) -> None:
        detail = await async_client.partner.v1.showtime.details.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
            include_production_details=True,
            iso_date_bounds={
                "iso_end_date": parse_datetime("2019-02-26T07:00:00Z"),
                "iso_start_date": parse_datetime("2019-02-25T07:00:00Z"),
            },
            local_date_bounds={
                "local_end_date": "localEndDate",
                "local_start_date": "localStartDate",
            },
            marketplace_id="marketplaceId",
            production_ids=["string"],
        )
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_for_multiple_venues(self, async_client: AsyncAtomTickets) -> None:
        response = await async_client.partner.v1.showtime.details.with_raw_response.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        detail = await response.parse()
        assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_for_multiple_venues(self, async_client: AsyncAtomTickets) -> None:
        async with async_client.partner.v1.showtime.details.with_streaming_response.get_for_multiple_venues(
            venue_ids=["C0057070265", "C00110921804", "C00401723167", "C00928817799"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            detail = await response.parse()
            assert_matches_type(DetailGetForMultipleVenuesResponse, detail, path=["response"])

        assert cast(Any, response.is_closed) is True
